--[[
-- Copyright 2022 AKA Russell
--
-- This file is part of Scarlet.
--
-- Scarlet is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- Scarlet is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Scarlet.  If not, see <http://www.gnu.org/licenses/>.
--]]
--[[
-- This module defines the Swordswoman's powers. The Swordswoman is
-- a straight forward brute, with only two powers: the ability to
-- raise her shield to get some shield points, and a sword slash
-- that attacks all PC's.
--]]

local M = {}

local attacks = require 'combat/attack'
local combatstateops = require 'combat/combatstate'
local statuses = require 'data/statuses'
local statusops = require 'combat/statuses'
local pages = require 'pages'
local powers = require 'combat/powers'
local powerutils = require 'data/powerutils'

local function swordswipemessage(combatstate)
    local activecharacter = combatstateops.activecharacter(combatstate)
    return activecharacter.combatname 
            .. " sweeps across the battlefield, sword flashing."
end

M.swordswipe=pages.page(
    nil,
    nil,
    nil,
    function(combatstate)
        local activecharacter = combatstateops.activecharacter(combatstate)
        table.insert(combatstate.combatlog, swordswipemessage(combatstate))
        local opponents = combatstateops.activeopponents(combatstate)
        attacks.damage(combatstate, nil, opponents, activecharacter)
        powerutils.inflictcost(combatstate, M.swordswipe)
    end
)

M.swordswipe.cost = 5
M.swordswipe.numtargets = powers.ALL_OPPONENTS
M.swordswipe.stats = {"power"}
M.swordswipe.damage = powers.DAMAGES
M.swordswipe.description = "The Swordswoman slashes all enemies with her sword."
M.swordswipe.aiexecution = function() return M.swordswipe end
M.swordswipe.damage = powers.DAMAGES
M.swordswipe.targets = combatstateops.activeopponents

local function inflictshieldstatus(user, combatstate)
    local duration = user.statistics.power
    local armorstatus = statuses["s-armor"]
    statusops.addstatus(user, armorstatus, duration, user, combatstate)
end

M.raiseshield=pages.page(
    nil,
    nil,
    nil,
    function(combatstate)
        local activecharacter = combatstateops.activecharacter(combatstate)
        local msg = activecharacter.combatname .. "'s shield flashes!"
        table.insert(combatstate.combatlog, msg)
        inflictshieldstatus(activecharacter, combatstate)
        powerutils.inflictcost(combatstate, M.raiseshield)
    end
)

M.raiseshield.cost = 3
M.raiseshield.numtargets = 0
M.raiseshield.damage = powers.NEITHER
M.raiseshield.stats = {"power"}
M.raiseshield.description = "The Swordswoman raised her shield and blocks some attacks."
M.raiseshield.aiexecution = function() return M.raiseshield end
M.raiseshield.damage = powers.NEITHER
M.raiseshield.targets = powers.activeallies

return M
