--[[
-- Copyright 2019 AKA Russell
--
-- This file is part of Scarlet.
--
-- Scarlet is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- Scarlet is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Scarlet.  If not, see <http://www.gnu.org/licenses/>.
--]]
--
--[[
-- Defines a simple page that displays the list of commands available in story mode.
--]]
--
local M = {}

local fonts = LOVE and require "ui/fonts"
local pages = require 'pages'

local function commandchoices(uistate, uichoices)
    local storyui = require 'story/storyui'
    local choices = {_keys={}}
    for _, key in ipairs(uichoices._keys) do
        choices[key] = uichoices[key]
        table.insert(choices._keys, key)
    end
    choices.backspace = storyui.page(uistate.core.gamestate.storypagename)
    table.insert(choices._keys, "backspace")
    return choices
end

local function commandsgui(uistate)
    local gui = uistate.gui
    local pc = uistate.core.gamestate.characters.pc
    local text = {
        o="(o)ptions:         Options screen",
        c="(c)haracter:      Character screen",
        t="(t)itle:              Title screen",
        s="(s)ave:             Save Game",
        l="(l)oad:              Load Game",
        ["+"]="(+):                  Increase story font size",
        ["-"]="(-):                   Decrease story font size",
        f1="(F1) Hairstyle:   " .. pc.attributes.hairstyle
    }
    local count = 2
    for _, slot in ipairs(pc.clothing._keys) do
        text[slot] = string.format(
            "(F%d) %s:        %s",
             count,
             slot,
             pc.clothing[slot].name
        )
        count = count + 1
    end
    local width = 0
    local font = fonts.button(uistate.core.gamestate.options.buttonfont)
    for _,commandtext in pairs(text) do
        local fontwidth = font:getWidth(commandtext)
        if width < fontwidth then
            width = fontwidth
        end
    end
    local titlefont = fonts.title(uistate.core.gamestate.options.titlefont)
    local explanation = "Commands used on the previous page:"
    local explanationwidth = titlefont:getWidth(explanation) + 5
    local height = font:getHeight()
    gui.Label(
        explanation,
        {font=titlefont},
        gui.layout:row(explanationwidth, height)
    )
    gui.Button(text.o, {font=font, align="left", id="o"}, gui.layout:row())
    gui.Button(text.c, {font=font, align="left", id="c"}, gui.layout:row())
    gui.Button(text.t, {font=font, align="left", id="t"}, gui.layout:row())
    gui.Button(text.s, {font=font, align="left", id="s"}, gui.layout:row())
    gui.Button(text.l, {font=font, align="left", id="l"}, gui.layout:row())
    gui.Button(text["+"], {font=font, align="left", id="+"}, gui.layout:row())
    gui.Button(text["-"], {font=font, align="left", id="-"}, gui.layout:row())
    gui.Button(text.f1, {font=font, align="left", id="f1"}, gui.layout:row())
    local count = 2
    for _, slot in ipairs(pc.clothing._keys) do
        local id = "f" .. tostring(count)
        gui.Button(
            text[slot],
            {font=font, align="left", id=id}, gui.layout:row()
        )
        count = count + 1
    end

    gui.Button("(<==) Return to story", {font=titlefont, id="backspace"}, gui.layout:row(nil, titlefont:getHeight()))
end

function M.commands(choices)
    local page = pages.page(
        nil,
        nil,
        function(uistate) return commandchoices(uistate, choices) end
    )
    page.drawgui = commandsgui
    return page
end

return M
