--[[
-- Copyright 2016 AKA Russell
--
-- This file is part of Scarlet.
--
-- Scarlet is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- Scarlet is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with Scarlet.  If not, see <http://www.gnu.org/licenses/>.
--]]
--
--[[ This module contains a collection of functions that help in building
-- buttons with a GUI toolkit that matches the SUIT interface.
--]]

local M = {}
local fonts = require 'ui/fonts'

--[[
-- A bit of syntactic sugar to simplify building a button in Scarlet with a
-- GUI toolkit that matches the SUIT layout.
--
-- These buttons are all built with the 'fonts.button' font.
--
-- uistate - The current state of the UI
-- label - The text to display in the button
-- shortcutId - The name of the keyboard key that triggers this button. This
--  is also used as the button's id.
-- layoutFunction - The (side-effectful) function that should be used to
--  place the button in the appropriate space. The function takes a table
--  representing the GUI (i.e. the SUIT module), and returns the x-coordinate,
--  y-coordinate, width and height of the widget in that order
--
--  This function returns the metadata about the constructed widgit in the
--  same format as SUIT's button function.
--]]
function M.buildButton(uistate, label, shortcutId, layoutFunction)
    local buttonfontsize = uistate.core.gamestate.options.buttonfont
    return uistate.gui.Button(
        label,
        {id=shortcutId, font=fonts.button(buttonfontsize)},
        layoutFunction(uistate.gui)
    )
end

return M
